aboutsummaryrefslogtreecommitdiffstats
path: root/railties/guides/rails_guides/generator.rb
diff options
context:
space:
mode:
authorXavier Noria <fxn@hashref.com>2011-05-14 11:21:27 +0200
committerXavier Noria <fxn@hashref.com>2011-05-14 11:21:27 +0200
commitd49113023676fbf0b6653730f5bde759990caede (patch)
treede8a47655ad3a1fa1e73dbc307ec9b806637b3ec /railties/guides/rails_guides/generator.rb
parentdb886c817c3620ceaa68a988947e49e5219532fd (diff)
parente5524d538c0d0f39d655a78fc45d2122c0ff2f2a (diff)
downloadrails-d49113023676fbf0b6653730f5bde759990caede.tar.gz
rails-d49113023676fbf0b6653730f5bde759990caede.tar.bz2
rails-d49113023676fbf0b6653730f5bde759990caede.zip
Merge branch 'master' of git://github.com/lifo/docrails
Conflicts: actionpack/lib/action_view/helpers/date_helper.rb railties/lib/rails/generators/rails/app/templates/config/initializers/wrap_parameters.rb.tt
Diffstat (limited to 'railties/guides/rails_guides/generator.rb')
-rw-r--r--railties/guides/rails_guides/generator.rb9
1 files changed, 5 insertions, 4 deletions
diff --git a/railties/guides/rails_guides/generator.rb b/railties/guides/rails_guides/generator.rb
index 154355cac1..14d671c8f3 100644
--- a/railties/guides/rails_guides/generator.rb
+++ b/railties/guides/rails_guides/generator.rb
@@ -38,9 +38,10 @@
# Note that if you are working on a guide generation will by default process
# only that one, so ONLY is rarely used nowadays.
#
# LANGUAGE
# Use LANGUAGE when you want to generate translated guides in <tt>source/<LANGUAGE></tt>
# folder (such as <tt>source/es</tt>). Ignore it when generating English guides.
#
# EDGE
# Set to "1" to indicate generated guides should be marked as edge. This
@@ -67,7 +68,7 @@ module RailsGuides
GUIDES_RE = /\.(?:textile|html\.erb)$/
def initialize(output=nil)
- @lang = ENV['LANGUAGE']
+ @lang = ENV['GUIDES_LANGUAGE']
initialize_dirs(output)
create_output_dir_if_needed
set_flags_from_environment
@@ -38,9 +38,10 @@
# only that one, so ONLY is rarely used nowadays.
#
-# LANGUAGE
-# Use LANGUAGE when you want to generate translated guides in <tt>source/<LANGUAGE></tt>
-# folder (such as <tt>source/es</tt>). Ignore it when generating English guides.
+# GUIDES_LANGUAGE
+# Use GUIDES_LANGUAGE when you want to generate translated guides in
+# <tt>source/<GUIDES_LANGUAGE></tt> folder (such as <tt>source/es</tt>).
+# Ignore it when generating English guides.
#
# EDGE